@@ -6,23 +6,22 @@ test_that("unregularized gaussian models work as expected", {
 
   lm_fit <- lm(y ~ as.matrix(x))
 
-  g <- SLOPE(x,
-           y,
-           family = "gaussian",
-           alpha = 1e-12)
+  g <- SLOPE(x, y, family = "gaussian", alpha = 1e-12)
 
   expect_equivalent(coef(lm_fit),
-                    coef(g),
-                    tol = 1e-3)
+    coef(g),
+    tol = 1e-3
+  )
 })
 
 test_that("wide and tall inputs work correctly", {
-
   set.seed(926)
 
-  grid <- expand.grid(n = c(50, 100),
-                      p = c(50, 100),
-                      density = c(1, 0.5))
+  grid <- expand.grid(
+    n = c(50, 100),
+    p = c(50, 100),
+    density = c(1, 0.5)
+  )
 
   for (i in seq_len(nrow(grid))) {
     n <- grid$n[i]
@@ -58,4 +57,4 @@ test_that("diagonal X, known solution", {
   beta <- coef(res)
 
   expect_equal(beta, c(4, 3, 2, 1), check.attributes = FALSE)
-})
\ No newline at end of file
+})
